@@ -480,8 +480,8 @@ from data.models.models import HardwareStats, DataTransformer, DataTransformerCo
 #                                                      extra=1,exclude =['updated_at','created_at'],formset=DataTransformerForm)
 
 class DataConstantsTransformerForm(forms.ModelForm):
-    id = forms.CharField(required=False,
-                         widget=forms.HiddenInput(attrs={'class': 'form-control'}))
+    id = forms.UUIDField(required=False,
+                         widget=forms.HiddenInput(attrs={'class': 'form-control'}),initial=uuid.uuid4)
 
     index = forms.IntegerField(required=False,
                                widget=forms.HiddenInput(attrs={'class': 'form-control'}),
@@ -497,8 +497,8 @@ class DataConstantsTransformerForm(forms.ModelForm):
 
 
 class HardwareTransformerForm(forms.ModelForm):
-    id = forms.CharField(required=False,
-                         widget=forms.HiddenInput(attrs={'class': 'form-control'}))
+    id = forms.UUIDField(required=False,
+                         widget=forms.HiddenInput(attrs={'class': 'form-control'}),initial=uuid.uuid4)
     index = forms.IntegerField(required=False,
                                widget=forms.HiddenInput(attrs={'class': 'form-control'}),
                                initial=0)
@@ -511,8 +511,8 @@ class HardwareTransformerForm(forms.ModelForm):
 
 
 class HardwareStatsTransformerForm(forms.ModelForm):
-    id = forms.CharField(required=False,
-                         widget=forms.HiddenInput(attrs={'class': 'form-control'}))
+    id = forms.UUIDField(required=False,
+                         widget=forms.HiddenInput(attrs={'class': 'form-control'}),initial=uuid.uuid4)
     index = forms.IntegerField(required=False,
                                widget=forms.HiddenInput(attrs={'class': 'form-control'}),
                                initial=0)
@@ -567,9 +567,9 @@ from django.utils.safestring import mark_safe
 
 
 class DataTransform(forms.ModelForm):
-    id = forms.CharField(required=False,
+    id = forms.UUIDField(required=False,
                          widget=forms.HiddenInput(attrs={'class': 'form-control'}),
-                         initial=uuid.uuid4())
+                         initial=uuid.uuid4)
     accessory = forms.ModelChoiceField(required=False, queryset=Accessory.objects.all(),
                                        widget=forms.HiddenInput(attrs={'class': 'form-control'}))
 
@@ -582,13 +582,6 @@ class DataTransform(forms.ModelForm):
         print('Init Data Transform')
 
         super(DataTransform, self).__init__(*args, **kwargs)
-        if self.fields['parent'] is not None and self.fields['parent'] != '':
-            print(str(self.fields['parent']))
-            print(str(self.data))
-            print(str(self.initial))
-            print(str(self.initial['parent']))
-            print(str(self.parent))
-            self.fields['accessory'].initial = str(DataTransformer.objects.get(self.data['parent'].pk).first().accessory.pk)
 
         try:
             if self.instance.get_children().count() >= 0:
@@ -721,8 +714,8 @@ dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransf
 
 
 class DataTransformRoot(forms.ModelForm):
-    id = forms.CharField(required=False,
-                         widget=forms.HiddenInput(attrs={'class': 'form-control'}),initial=uuid.uuid4())
+    id = forms.UUIDField(required=False,
+                         widget=forms.HiddenInput(attrs={'class': 'form-control'}),initial=uuid.uuid4)
     accessory = forms.ModelChoiceField(required=True, queryset=Accessory.objects.all(),
                                        widget=forms.HiddenInput(attrs={'class': 'form-control'}))
     type = forms.ModelChoiceField(required=True, queryset=DataTransformerTypes.objects.all())
@@ -731,7 +724,7 @@ class DataTransformRoot(forms.ModelForm):
     #     super(HardwareTypeForm, self).__init__(*args, **kwargs)
     def __init__(self, *args, **kwargs):
         super(DataTransformRoot, self).__init__(*args, **kwargs)
-        self.fields['accessory'].initial = str(self.instance.accessory.pk)
+        # self.fields['accessory'].initial = str(self.instance.accessory.pk)
 
         # types = list(
         #     DataTransformerTypes.objects.all().values_list('type', 'type'))
